@@ -100,13 +100,13 @@ class Property(object):
 
         value = document_instance._doc.get(self.name)
         if value is not None:
-            value = self.to_python(value)
+            value = self._to_python(value)
         
         return value
 
     def __set__(self, document_instance, value):
         value = self.validate(value, required=False)
-        document_instance._doc[self.name] = self.to_json(value)
+        document_instance._doc[self.name] = self._to_json(value)
 
     def __delete__(self, document_instance):
         pass
@@ -146,6 +146,16 @@ class Property(object):
     def empty(self, value):
         """ test if value is empty """
         return not value or value is None
+        
+    def _to_python(self, value):
+        if value == None:
+            return value    
+        return self.to_python(value)
+        
+    def _to_json(self, value):
+        if value == None:
+            return value    
+        return self.to_json(value)
 
     def to_python(self, value):
         """ convert to python type """
@@ -507,7 +517,7 @@ class StringListProperty(ListProperty):
     def __init__(self, verbose_name=None, default=None, 
             required=False, **kwds):
         super(StringListProperty, self).__init__(verbose_name=verbose_name, 
-            default=default, required=required, item_type=unicode,**kwds)
+            default=default, required=required, item_type=basestring,**kwds)
 
 # structures proxy
 
@@ -733,7 +743,7 @@ def validate_content(value, item_type=None):
         value = validate_list_content(value, item_type=item_type)
     elif isinstance(value, dict):
         value = validate_dict_content(value, item_type=item_type)
-    elif item_type is not None and type(value) != item_type:
+    elif item_type is not None and not isinstance(value, item_type):
         raise BadValueError(
             'Items  must all be in %s' % item_type)
     elif type(value) not in ALLOWED_PROPERTY_TYPES:
